VOL-3314: ONU discovered entry is not cleared in OLT adapter on ONU
startup failure event
Bump minor version post VOLTHA2.4 branch out

Change-Id: I8b0d14283baecec666af3c7f5d7ba8604f517773
diff --git a/VERSION b/VERSION
index 3f5987a..69fa968 100644
--- a/VERSION
+++ b/VERSION
@@ -1 +1 @@
-2.4.9
+2.5.0-dev
diff --git a/internal/pkg/core/device_handler.go b/internal/pkg/core/device_handler.go
index d291935..91c9ced 100644
--- a/internal/pkg/core/device_handler.go
+++ b/internal/pkg/core/device_handler.go
@@ -1243,8 +1243,10 @@
 func (dh *DeviceHandler) updateOnuStates(onuDevice *voltha.Device, onuInd *oop.OnuIndication) error {
 	ctx := context.TODO()
 	logger.Debugw("onu-indication-for-state", log.Fields{"onuIndication": onuInd, "device-id": onuDevice.Id, "operStatus": onuDevice.OperStatus, "adminStatus": onuDevice.AdminState})
-	if onuInd.AdminState == "down" {
-		// The ONU has gone admin_state "down" and we expect the ONU to send discovery again
+	if onuInd.AdminState == "down" || onuInd.OperState == "down" {
+		// The ONU has gone admin_state "down" or oper_state "down" - we expect the ONU to send discovery again
+		// The ONU admin_state is "up" while "oper_state" is down in cases where ONU activation fails. In this case
+		// the ONU sends Discovery again.
 		dh.discOnus.Delete(onuDevice.SerialNumber)
 		// Tests have shown that we sometimes get OperState as NOT down even if AdminState is down, forcing it
 		if onuInd.OperState != "down" {